==> openconfig-models-15.1.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/system/logging/rev181121/logging/remote/top/remote/servers/RemoteServerBuilder.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.LoggingSelectorsTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.Config;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.State;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.selectors.top.Selectors;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.types.inet.rev210107.Host;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RemoteServerBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RemoteServerBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new RemoteServerBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RemoteServerBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RemoteServerBuilder
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class RemoteServerBuilder implements Builder<RemoteServer> {

    private Config _config;
    private Host _host;
    private Selectors _selectors;
    private State _state;
    private RemoteServerKey key;


    Map<Class<? extends Augmentation<RemoteServer>>, Augmentation<RemoteServer>> augmentation = Collections.emptyMap();

    public RemoteServerBuilder() {
    }
    
    
    
    public RemoteServerBuilder(LoggingSelectorsTop arg) {
        this._selectors = arg.getSelectors();
    }
    

    public RemoteServerBuilder(RemoteServer base) {
        Map<Class<? extends Augmentation<RemoteServer>>, Augmentation<RemoteServer>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this.key = base.key();
        this._host = base.getHost();
        this._config = base.getConfig();
        this._selectors = base.getSelectors();
        this._state = base.getState();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>LoggingSelectorsTop</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof LoggingSelectorsTop) {
            this._selectors = ((LoggingSelectorsTop)arg).getSelectors();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[LoggingSelectorsTop]");
    }

    public RemoteServerKey key() {
        return key;
    }
    
    public Config getConfig() {
        return _config;
    }
    
    public Host getHost() {
        return _host;
    }
    
    public Selectors getSelectors() {
        return _selectors;
    }
    
    public State getState() {
        return _state;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RemoteServer>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    public RemoteServerBuilder withKey(final RemoteServerKey key) {
        this.key = key;
        return this;
    }
    
    public RemoteServerBuilder setConfig(final Config value) {
        this._config = value;
        return this;
    }
    
    public RemoteServerBuilder setHost(final Host value) {
        this._host = value;
        return this;
    }
    
    public RemoteServerBuilder setSelectors(final Selectors value) {
        this._selectors = value;
        return this;
    }
    
    public RemoteServerBuilder setState(final State value) {
        this._state = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public RemoteServerBuilder addAugmentation(Augmentation<RemoteServer> augmentation) {
        Class<? extends Augmentation<RemoteServer>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public RemoteServerBuilder removeAugmentation(Class<? extends Augmentation<RemoteServer>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public RemoteServer build() {
        return new RemoteServerImpl(this);
    }

    private static final class RemoteServerImpl
        extends AbstractAugmentable<RemoteServer>
        implements RemoteServer {
    
        private final Config _config;
        private final Host _host;
        private final Selectors _selectors;
        private final State _state;
        private final RemoteServerKey key;
    
        RemoteServerImpl(RemoteServerBuilder base) {
            super(base.augmentation);
            if (base.key() != null) {
                this.key = base.key();
            } else {
                this.key = new RemoteServerKey(base.getHost());
            }
            this._host = key.getHost();
            this._config = base.getConfig();
            this._selectors = base.getSelectors();
            this._state = base.getState();
        }
    
        @Override
        public RemoteServerKey key() {
            return key;
        }
        
        @Override
        public Config getConfig() {
            return _config;
        }
        
        @Override
        public Host getHost() {
            return _host;
        }
        
        @Override
        public Selectors getSelectors() {
            return _selectors;
        }
        
        @Override
        public State getState() {
            return _state;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = RemoteServer.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return RemoteServer.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return RemoteServer.bindingToString(this);
        }
    }
}

==> openconfig-models-15.3.0-sources.jar: org/opendaylight/yang/gen/v1/http/openconfig/net/yang/system/logging/rev181121/logging/remote/top/remote/servers/RemoteServerBuilder.java <==
package org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.LoggingSelectorsTop;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.Config;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.remote.top.remote.servers.remote.server.State;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.system.logging.rev181121.logging.selectors.top.Selectors;
import org.opendaylight.yang.gen.v1.http.openconfig.net.yang.types.inet.rev210107.Host;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RemoteServer} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RemoteServer createRemoteServer(int fooXyzzy, int barBaz) {
 *         return new RemoteServerBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RemoteServer, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RemoteServer
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class RemoteServerBuilder implements Builder<RemoteServer> {

    private Config _config;
    private Host _host;
    private Selectors _selectors;
    private State _state;
    private RemoteServerKey key;


    Map<Class<? extends Augmentation<RemoteServer>>, Augmentation<RemoteServer>> augmentation = Collections.emptyMap();

    public RemoteServerBuilder() {
    }
    
    
    
    public RemoteServerBuilder(LoggingSelectorsTop arg) {
        this._selectors = arg.getSelectors();
    }
    

    public RemoteServerBuilder(RemoteServer base) {
        Map<Class<? extends Augmentation<RemoteServer>>, Augmentation<RemoteServer>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this.key = base.key();
        this._host = base.getHost();
        this._config = base.getConfig();
        this._selectors = base.getSelectors();
        this._state = base.getState();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>LoggingSelectorsTop</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof LoggingSelectorsTop) {
            this._selectors = ((LoggingSelectorsTop)arg).getSelectors();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[LoggingSelectorsTop]");
    }

    public RemoteServerKey key() {
        return key;
    }
    
    public Config getConfig() {
        return _config;
    }
    
    public Host getHost() {
        return _host;
    }
    
    public Selectors getSelectors() {
        return _selectors;
    }
    
    public State getState() {
        return _state;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RemoteServer>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    public RemoteServerBuilder withKey(final RemoteServerKey key) {
        this.key = key;
        return this;
    }
    
    public RemoteServerBuilder setConfig(final Config value) {
        this._config = value;
        return this;
    }
    
    public RemoteServerBuilder setHost(final Host value) {
        this._host = value;
        return this;
    }
    
    public RemoteServerBuilder setSelectors(final Selectors value) {
        this._selectors = value;
        return this;
    }
    
    public RemoteServerBuilder setState(final State value) {
        this._state = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public RemoteServerBuilder addAugmentation(Augmentation<RemoteServer> augmentation) {
        Class<? extends Augmentation<RemoteServer>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public RemoteServerBuilder removeAugmentation(Class<? extends Augmentation<RemoteServer>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public RemoteServer build() {
        return new RemoteServerImpl(this);
    }

    private static final class RemoteServerImpl
        extends AbstractAugmentable<RemoteServer>
        implements RemoteServer {
    
        private final Config _config;
        private final Host _host;
        private final Selectors _selectors;
        private final State _state;
        private final RemoteServerKey key;
    
        RemoteServerImpl(RemoteServerBuilder base) {
            super(base.augmentation);
            if (base.key() != null) {
                this.key = base.key();
            } else {
                this.key = new RemoteServerKey(base.getHost());
            }
            this._host = key.getHost();
            this._config = base.getConfig();
            this._selectors = base.getSelectors();
            this._state = base.getState();
        }
    
        @Override
        public RemoteServerKey key() {
            return key;
        }
        
        @Override
        public Config getConfig() {
            return _config;
        }
        
        @Override
        public Host getHost() {
            return _host;
        }
        
        @Override
        public Selectors getSelectors() {
            return _selectors;
        }
        
        @Override
        public State getState() {
            return _state;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = RemoteServer.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return RemoteServer.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return RemoteServer.bindingToString(this);
        }
    }
}
